@@ -1,16 +1,20 @@
 # oppia/models.py
 import json
 import datetime
+
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.db import models
 from django.db.models import Max, Sum, Q
 from django.utils.translation import ugettext_lazy as _
+
 from tastypie.models import create_api_key
+
 from xml.dom.minidom import *
 
 models.signals.post_save.connect(create_api_key, sender=User)
 
+
 class Course(models.Model):
     user = models.ForeignKey(User)
     created_date = models.DateTimeField('date created',default=datetime.datetime.now)
@@ -76,6 +80,13 @@ class Course(models.Model):
         last_week = datetime.datetime(now.year, now.month, now.day) - datetime.timedelta(days=7)
         return Tracker.objects.filter(course=self,
                                       tracker_date__gte=last_week).count()
+                                      
+    def has_quizzes(self):
+        quiz_count = Activity.objects.filter(section__course=self,type='quiz').count()
+        if quiz_count > 0:
+            return True
+        else:
+            return False
     
 class Tag(models.Model):
     name = models.TextField(blank=False)
@@ -301,6 +312,16 @@ class Tracker(models.Model):
         if time['total'] is None:
             return 0
         return time['total']
+    
+    def get_lang(self):
+        try:
+            json_data = json.loads(self.data)
+        except ValueError:
+            return None
+        
+        if 'lang' in json_data:
+            return json_data['lang']
+        
          
 class CourseDownload(models.Model):
     user = models.ForeignKey(User)
